@@ -36,6 +36,17 @@ SPOKE_LOCAL_PORTFOLIO = "spoke-local-portfolio"
 ACTION = "action"
 
 AFFINITY = "affinity"
+AFFINITY_REGION = "region"
+AFFINITY_ACCOUNT = "account"
+AFFINITY_ACCOUNT_AND_REGION = "account-and-region"
+
+ALL_SECTION_NAMES = [
+    LAUNCHES,
+    SPOKE_LOCAL_PORTFOLIOS,
+    LAMBDA_INVOCATIONS,
+    CODE_BUILD_RUNS,
+    ASSERTIONS,
+]
 
 RESULTS_DIRECTORY = "results"
 
@@ -66,7 +77,6 @@ EXECUTION_MODE_SPOKE = "spoke"
 EXECUTION_MODE_DEFAULT = EXECUTION_MODE_HUB
 EXECUTION_SPOKE_CODEBUILD_PROJECT_NAME = "servicecatalog-puppet-deploy-in-spoke"
 
-
 SHARING_MODE_ACCOUNT = "ACCOUNT"
 SHARING_MODE_AWS_ORGANIZATIONS = "AWS_ORGANIZATIONS"
 SHARING_MODE_DEFAULT = SHARING_MODE_ACCOUNT
@@ -83,28 +93,43 @@ PUPPET_ROLE_PATH_DEFAULT = "/servicecatalog-puppet/"
 PUPPET_ROLE_PATH_ENVIRONMENTAL_VARIABLE_NAME = "PUPPET_ROLE_PATH"
 PUPPET_ROLE_PATH_SSM_PARAMETER_VARIABLE_NAME = "/servicecatalog-puppet/puppet-role/path"
 
-
 DEPLOY_ENVIRONMENT_COMPUTE_TYPE_DEFAULT = "BUILD_GENERAL1_SMALL"
 
-
 CONFIG_IS_CACHING_ENABLED = "CONFIG_IS_CACHING_ENABLED"
 
-
 START_SHARED_SCHEDULER_COMMAND = "luigid --background --pidfile luigi.pid --logdir results/logs --state-path results/state"
 
-
 CONFIG_REGIONS = "regions"
 CONFIG_SHOULD_COLLECT_CLOUDFORMATION_EVENTS = "should_collect_cloudformation_events"
 CONFIG_SHOULD_USE_SHARED_SCHEDULER = "should_use_shared_scheduler"
 CONFIG_SHOULD_EXPLODE_MANIFEST = "should_explode_manifest"
 
-
 PUBLISHED_VERSION = pkg_resources.require("aws-service-catalog-puppet")[0].version
 VERSION_OVERRIDE = "SCP_VERSION_OVERRIDE"
 VERSION = os.getenv(VERSION_OVERRIDE, PUBLISHED_VERSION)
 
-
 PRODUCT_GENERATION_METHOD_DEFAULT = "copy"
 
-
 LUIGI_DEFAULT_LOG_LEVEL = "INFO"
+
+ALL_SECTION_NAME_SINGULAR_AND_PLURAL_LIST = [
+    (LAUNCH, LAUNCHES),
+    (SPOKE_LOCAL_PORTFOLIO, SPOKE_LOCAL_PORTFOLIOS),
+    (LAMBDA_INVOCATION, LAMBDA_INVOCATIONS),
+    (CODE_BUILD_RUN, CODE_BUILD_RUNS),
+    (ASSERTION, ASSERTIONS),
+]
+
+SECTION_NAME_SINGULAR_AND_PLURAL_LIST_THAT_SUPPORTS_PARAMETERS = [
+    (LAUNCH, LAUNCHES),
+    (LAMBDA_INVOCATION, LAMBDA_INVOCATIONS),
+    (CODE_BUILD_RUN, CODE_BUILD_RUNS),
+]
+
+SECTION_SINGULAR_TO_PLURAL = {
+    LAUNCH: LAUNCHES,
+    SPOKE_LOCAL_PORTFOLIO: SPOKE_LOCAL_PORTFOLIOS,
+    LAMBDA_INVOCATION: LAMBDA_INVOCATIONS,
+    CODE_BUILD_RUN: CODE_BUILD_RUNS,
+    ASSERTION: ASSERTIONS,
+}
